/* This file is part of Wike (com.github.hugolabe.Wike)
SPDX-FileCopyrightText: 2021-25 Hugo Olabera
SPDX-License-Identifier: GPL-3.0-or-later
*/


/* General */

#mw-mf-page-center {
  background-color: #fdf6e3 !important;
}

.mw-body {
  background-color: #fdf6e3 !important;
  color: #453530 !important;
}

/* Main content */

.infobox, .infobox_v2, .infobox_v3 {
  background-color: #fefcf5 !important;
}

.gallerybox .thumb, .flexquote {
  background-color: #fefcf5 !important;
}

.wikitable {
  background: transparent !important;
}
