/* This file is part of Wike (com.github.hugolabe.Wike)
SPDX-FileCopyrightText: 2021-25 Hugo Olabera
SPDX-License-Identifier: GPL-3.0-or-later
*/


/* General */

#mw-mf-page-center {
  background-color: transparent !important;
}

#mw-notification-area {
  display: none !important;
}

/* Header and footer */

header.header-container, footer.minerva-footer {
  display: none !important;
}

.banner-container {
  display: none !important;
}

/* Pre content */

#frb-inline {
  display: none !important;
}

ul#page-actions, .page-actions-menu {
  display: none !important;
}

.pre-content .minerva__tab-container {
  display: none !important;
}

/* Post content */

.post-content .language-selector {
  display: none !important;
}

.mw-mf-linked-projects {
  display: none !important;
}

/* Main content */

h1 {
  color: #c01c28 !important;
  font-size: 2em !important;
}

.section-heading {
  border-bottom: none !important;
  margin-top: 0.5em !important;
  margin-bottom: 0 !important;
  font-family: inherit !important;
}

.hatnote, .rellink, .dablink {
  background-color: transparent !important;
  padding-left: 0 !important;
  font-style: italic !important;
}

#toc, .toc {
  display: none !important;
}

.mw-editsection, .mw-editsection-like, .cleanup, .ambox, .asbox {
  display: none !important;
}

.sistersitebox, .sisterproject.haudio {
  display: none !important;
}

.boilerplate {
  display: none !important;
}

.noprint.selfref {
  display: none !important;
}

.mwe-popups .mwe-popups-settings-button {
  display: none !important;
}

/* Local Wikipedias (es) */

.noprint.caja {
  display: none !important;
}
