/* This file is part of Wike (com.github.hugolabe.Wike)
SPDX-FileCopyrightText: 2021-25 Hugo Olabera
SPDX-License-Identifier: GPL-3.0-or-later
*/


/* Sepia theme */

:root {
  --window-bg-color: #fdf8e8;
  --headerbar-bg-color: #fdf6e3;
  --headerbar-backdrop-color: #e9e3d1;
  --sidebar-bg-color: #e9e3d1;
  --sidebar-backdrop-color: #e9e3d1;
  --secondary-sidebar-bg-color: #f1ead8;
  --secondary-sidebar-backdrop-color: #f1ead8;
  --overview-bg-color: #e9e3d1;
  --view-bg-color: #fefdf6;
  --card-bg-color: #fefdf6;
  --dialog-bg-color: #fdf8e8;
  --popover-bg-color: #fdf8e8;
  --accent-bg-color: var(--orange-4);
  --accent-color: var(--orange-5);
}
